package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`/@`!````K"%```````!``````````)#3````
M`````````$``.``)`$``'``;``8````%````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````.2^````````Y+X`````````
M`"````````$````&````P,T```````#`S6```````,#-8```````H`0`````
M```(%0``````````(````````@````8```#8S0```````-C-8```````V,U@
M```````@`@```````"`"````````"``````````$````!````%0"````````
M5`)```````!4`D```````$0`````````1``````````$`````````%#E=&0$
M````>+@```````!XN$```````'BX0```````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````,#-````````P,U@``````#`S6``
M`````$`"````````0`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````(`````0`
M```4`````P```$=.50#-N/`;_N5/(P5&G6K#RJE@S6JUM1$```!&````!```
M``@````@'!``!4`$ABH"0`"0A@&HPBD`($D@!`NXHCA%N@0""D8```!'````
M2P```%````!1````5P```%D```!;````7P```&$`````````8P```&8```!G
M````:```````````````>_!*:V[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#GQ!
MCL6XC?$.U634?-EQ6!SB1\8!K$OCP+KCDGS"Y3\L^J%L8+,!BV]J"4/6A_F<
M@6:OS&;%N9Q`0D75[,2)!9"(!W#3.?*+'`P4XI[)U;)QVLWCGC-BV^T,.I<+
M5J2;EJ?=HVM_J9R;X:<""@J*$%>CX/M)````````````````````````````
M`````````%0!```2`````````````````````````#X"```2````````````
M`````````````+T"```2`````````````````````````)("```2````````
M`````````````````!$````@`````````````````````````,0"```2````
M`````````````````````%`#```2`````````````````````````-,````2
M`````````````````````````-D"```2`````````````````````````#@#
M```2`````````````````````````#`#```2````````````````````````
M`*\````2`````````````````````````!<$```2````````````````````
M`````$\!```2`````````````````````````/P"```2````````````````
M`````````.<"```2`````````````````````````*P"```2````````````
M`````````````$D#```2`````````````````````````&T#```2````````
M`````````````````+@!```2`````````````````````````'@!```2````
M`````````````````````.X"```2`````````````````````````.$````2
M``````````````````````````("```2`````````````````````````&L"
M```2`````````````````````````*,"```2````````````````````````
M`)\!```2`````````````````````````'L"```2````````````````````
M`````)H"```2`````````````````````````.\!```2````````````````
M`````````-("```2`````````````````````````#D"```2````````````
M`````````````*(#```2`````````````````````````)L#```2````````
M`````````````````(8!```2`````````````````````````&`#```2````
M`````````````````````"T````@`````````````````````````!`#```2
M`````````````````````````'@````2``````````````````````````\!
M```2`````````````````````````%<"```2````````````````````````
M`/L!```2`````````````````````````+X````2````````````````````
M`````*T!```2`````````````````````````&H````2````````````````
M`````````%D!```2`````````````````````````!<#```2````````````
M`````````````.0!```2`````````````````````````!P!```2````````
M`````````````````,H"```2`````````````````````````#@!```2````
M`````````````````````#("```2`````````````````````````(P#```2
M`````````````````````````'0#```2`````````````````````````,8!
M```2`````````````````````````)0#```2````````````````````````
M`.`"```2`````````````````````````#P````@````````````````````
M`````/,````2`````````````````````````%D#```2````````````````
M`````````)8!```2`````````````````````````"4#```2````````````
M`````````````(T"```2`````````````````````````$\"```2````````
M``````````````````(#```2`````````````````````````(<````2````
M`````````````````````%`````@`````````````````````````/4"```2
M`````````````````````````'X#```2`````````````````````````-0!
M```2````T!M``````````````````"`$```2``T``%A```````!O````````
M`.X#```2``X`9%E``````````````````$4$```2``T`<$A```````!^"P``
M`````*\#```2``T`H!]````````,`@```````/0#```2``T`($)````````%
M`````````+,$```2``T`,$)```````"S`0```````.`$```2``T`<%A`````
M```Z`````````*T$```2``L`(!M``````````````````/P$```2``T`\%-`
M```````(!````````-,#```0`!D`8-)@`````````````````"P$```2``T`
M\$-````````D`````````%\$```1``\`<%E````````$`````````-\#```0
M`!D`R.)@`````````````````*L$```2``T`X$!````````J`````````,`$
M```2``T`4$=````````?`0```````-($```2``T`P$9```````!4````````
M`%($```0`!@`0-)@`````````````````)X````2````T!Y`````````````
M`````#D$```2``T`($1```````"_`````````+0#```1`!D`<-)@```````(
M`````````,P#```0`!@`8-)@`````````````````+4#```A`!D`<-)@````
M```(`````````)0$```1`!@`6-)@```````(`````````$(#```1`!D`>-)@
M```````(`````````.0#```2``T`8%E````````"`````````&4!```2````
M$!Y``````````````````(0$```2``T`T%A```````")`````````%@$```2
M``T`K"%``````````````````%0$```@`!@`0-)@`````````````````"T!
M```1`!D`8-)@```````$`````````+8#```A`!D`<-)@```````(````````
M``4$```2``T`($=````````D`````````&X$```2``T`8$%```````"Y````
M``````(!```1`!D`:-)@```````!`````````)X$```2``T`X$1```````#;
M`0````````!L:6)P97)L+G-O+C4N,3@`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O
M7W5N9'5M<`!097)L7VYE=U-6<'8`4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R
M;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`&QI8F1L+G-O
M+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!O<&5N-C0`<F5A9`!?7V5R
M<FYO7VQO8V%T:6]N`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S
M90!L:6)C+G-O+C8`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?
M<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER
M`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S
M=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H
M:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`
M<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T
M`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S
M=&%R=%]M86EN`%]?96YV:7)O;@!L:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B
M87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T
M`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?
M8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F
M:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN
M=&5R;F%L<U]005)?0TQ%05)35$%#2P!84U]);G1E<FYA;'-?4$%27T)/3U0`
M1TQ)0D-?,BXR+C4`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N
M,@!'3$E"0U\R+C0``````@`#``(``@````(``@````(``@`"`````@````(`
M`@`$``(``@```````@```````P`"````!0`"`````@`#``(``@````8````'
M```````#``(````````````&```````"`````P`"``(````"``(```````(`
M```"``(``P`&```````"``8````!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$````!``(``0`"``$``@`!`````0`!``$````"``$``0````$`
M`0`!`"("```0````(````'4::0D```,`$@4````````!``4`<0(``!``````
M````E)&6!@``!P`>!0``$````'09:0D```8`*04``!````!R&6D)```%`#4%
M```0````%&EI#0``!`!!!0``$````'4::0D```(`$@4```````#XSV``````
M``8````E``````````````!@TF````````4```!D``````````````!HTF``
M``````4```!H``````````````!PTF````````4```!:``````````````!X
MTF````````4```!>```````````````8T&````````<````!````````````
M```@T&````````<````"```````````````HT&````````<````#````````
M```````PT&````````<````$```````````````XT&````````<````&````
M``````````!`T&````````<````'``````````````!(T&````````<````(
M``````````````!0T&````````<````)``````````````!8T&````````<`
M``!&``````````````!@T&````````<````*``````````````!HT&``````
M``<````+``````````````!PT&````````<````,``````````````!XT&``
M``````<````-``````````````"`T&````````<````.``````````````"(
MT&````````<````/``````````````"0T&````````<````0````````````
M``"8T&````````<````1``````````````"@T&````````<````2````````
M``````"HT&````````<````3``````````````"PT&````````<````4````
M``````````"XT&````````<````5``````````````#`T&````````<````6
M``````````````#(T&````````<````7``````````````#0T&````````<`
M```8``````````````#8T&````````<````9``````````````#@T&``````
M``<````:``````````````#HT&````````<````;``````````````#PT&``
M``````<````<``````````````#XT&````````<````=````````````````
MT6````````<````>```````````````(T6````````<````?````````````
M```0T6````````<````@```````````````8T6````````<````A````````
M```````@T6````````<````B```````````````HT6````````<````C````
M```````````PT6````````<````D```````````````XT6````````<````E
M``````````````!`T6````````<````F``````````````!(T6````````<`
M```G``````````````!0T6````````<````H``````````````!8T6``````
M``<````I``````````````!@T6````````<````J``````````````!HT6``
M``````<````K``````````````!PT6````````<````L``````````````!X
MT6````````<```!@``````````````"`T6````````<````M````````````
M``"(T6````````<````N``````````````"0T6````````<````O````````
M``````"8T6````````<````P``````````````"@T6````````<````Q````
M``````````"HT6````````<````R``````````````"PT6````````<````S
M``````````````"XT6````````<````T``````````````#`T6````````<`
M```U``````````````#(T6````````<````V``````````````#0T6``````
M``<````W``````````````#8T6````````<```!8``````````````#@T6``
M``````<````X``````````````#HT6````````<````Y``````````````#P
MT6````````<````[``````````````#XT6````````<````\````````````
M````TF````````<````]```````````````(TF````````<````^````````
M```````0TF````````<````_```````````````8TF````````<```!`````
M```````````@TF````````<```!!```````````````HTF````````<```!"
M```````````````PTF````````<```!$```````````````XTF````````<`
M``!%``````````````!(@^P(2(L%S;0@`$B%P'0%Z%L"``!(@\0(PP``````
M`/\UPK0@`/\EQ+0@``\?0`#_)<*T(`!H`````.G@_____R6ZM"``:`$```#I
MT/____\ELK0@`&@"````Z<#_____):JT(`!H`P```.FP_____R6BM"``:`0`
M``#IH/____\EFK0@`&@%````Z9#_____)9*T(`!H!@```.F`_____R6*M"``
M:`<```#I</____\E@K0@`&@(````Z6#_____)7JT(`!H"0```.E0_____R5R
MM"``:`H```#I0/____\E:K0@`&@+````Z3#_____)6*T(`!H#````.D@____
M_R5:M"``:`T```#I$/____\E4K0@`&@.````Z0#_____)4JT(`!H#P```.GP
M_O___R5"M"``:!````#IX/[___\E.K0@`&@1````Z=#^____)3*T(`!H$@``
M`.G`_O___R4JM"``:!,```#IL/[___\E(K0@`&@4````Z:#^____)1JT(`!H
M%0```.F0_O___R42M"``:!8```#I@/[___\E"K0@`&@7````Z7#^____)0*T
M(`!H&````.E@_O___R7ZLR``:!D```#I4/[___\E\K,@`&@:````Z4#^____
M)>JS(`!H&P```.DP_O___R7BLR``:!P```#I(/[___\EVK,@`&@=````Z1#^
M____)=*S(`!H'@```.D`_O___R7*LR``:!\```#I\/W___\EPK,@`&@@````
MZ>#]____);JS(`!H(0```.G0_?___R6RLR``:"(```#IP/W___\EJK,@`&@C
M````Z;#]____):*S(`!H)````.F@_?___R6:LR``:"4```#ID/W___\EDK,@
M`&@F````Z8#]____)8JS(`!H)P```.EP_?___R6"LR``:"@```#I8/W___\E
M>K,@`&@I````Z5#]____)7*S(`!H*@```.E`_?___R5JLR``:"L```#I,/W_
M__\E8K,@`&@L````Z2#]____)5JS(`!H+0```.D0_?___R52LR``:"X```#I
M`/W___\E2K,@`&@O````Z?#\____)4*S(`!H,````.G@_/___R4ZLR``:#$`
M``#IT/S___\E,K,@`&@R````Z<#\____)2JS(`!H,P```.FP_/___R4BLR``
M:#0```#IH/S___\E&K,@`&@U````Z9#\____)1*S(`!H-@```.F`_/___R4*
MLR``:#<```#I</S___\E`K,@`&@X````Z6#\____)?JR(`!H.0```.E0_/__
M_R7RLB``:#H```#I0/S___\EZK(@`&@[````Z3#\____)>*R(`!H/````.D@
M_/___R7:LB``:#T```#I$/S___\ETK(@`&@^````Z0#\____)<JR(`!H/P``
M`.GP^____R7"LB``:$````#IX/O___\ENK(@`&A!````Z=#[____);*R(`!H
M0@```.G`^____R6JLB``:$,```#IL/O___\EHK(@`&A$````Z:#[__]32(/L
M,(E\)!Q(B70D$$B-?"0<2(E4)`A(C70D$$B-5"0(Z.G]__^Z$!Y``+_0'D``
M2(G6Z-<X``"`/8BR(```=2_HV?S__TB%P$B)!<_"(``/A*8!``!(B<?H`?S_
M_XL]6[(@`.C&_?__QH"5"````(L]2;(@`.BT_?__@(BN!````HL]-[(@`.BB
M_?__@(BN!````8M$)!R->`5(8_](A?\/B!@!``#R2`\JQ_(/6`43F```9@\N
M!1.8```/AT0!``!(P><#Z+3\__](BTPD$$B)!3#"(`#'!2["(``$````2(L1
M2,=`"%E;0`!(QT`87%M``$B)$$B+%;FQ(`!(B5`0BU0D'(/Z`7XGC7+^3(T$
M]0@````Q]@\?@`````!(BWPQ"$B)?#`@2(/&"$PYQG7MC4H$2(L]X\$@`(/"
M`T4QP+X004``2&/)2,=$R/@`````2(G!Z%3]__^%P(G#=#M(BSVWP2``Z'+[
M__](C70D+#'`OQU:0`#H<1@``$B%P'0I2(L]E<$@`.CP^O__Z.O\__](@\0P
MB=A;PTB+/7S!(`#HU_W__XG#Z[5(BSUDP2``2(7_="3HHC8``.O$2(GX2(GZ
M2-'H@^(!2`G0\D@/*L#R#UC`Z=#^__](C70D++_264``Z`08``!(A<!(B04B
MP2``=(Q(B<?KO+\!````Z)G]___HU/S__S'M28G17DB)XDB#Y/!05$G'P&!9
M0`!(Q\'06$``2,?'H!]``.A[^___]&8N#Q^$``````"X9])@`%5(+6#28`!(
M@_@.2(GE=P)=P[@`````2(7`=/1=OV#28`#_X`\?@`````"X8-)@`%5(+6#2
M8`!(P?@#2(GE2(G"2,'J/T@!T$C1^'4"7<.Z`````$B%TG3T74B)QK]@TF``
M_^(/'X``````@#TIL"```'4154B)Y>A^____7<8%%K`@``'SPP\?0`!(@SU8
MJR```'0>N`````!(A<!T%%6_T,U@`$B)Y?_07>E[____#Q\`Z7/___\/'P!!
M5TR-1S@QR4%6055!5%532('L$`(``&8/'X0``````$F+%`A(B=!(B=9(P>`(
M2,'F&"4``/\`B?9("?!(B=9(P>X(@>8`_P``2`GP2(G62,'N&$`/MO9("?!(
MB=9(P>X@2(E$3(A(B?!(P>882,'@"(GV)0``_P!("?!(B=9(P>HX2,'N*('F
M`/\``$@)\$@)T$B)1$R02(/!"$B#^4`/A7O___](C40DB$B-M"3P`0``2(U0
M:&8N#Q^$``````!(BT+82#,"2(/""$@S0J!(,T*02(G!2`'`2,'I'T@)P8/A
M_TB)2A!(.?)UU$B+%TR+;R!,BT\(3(M7$$R+9QA,B>E(B=!(`TPDB$B)UDC!
MZ!M,B<U(P>8%2,'M`DV)X$@)\$P#1"202(G6B<!(]]9)B=9,C9P!F7F"6DR)
MR$R)T4CWT$PAR4PAUDPAX$G![@),B=-("<A(`UPDF$D!PTR)R$C!X!Y$B=E(
M"<6)[4B)Z$@AT$@)\$B)SDV-A`"9>8):2(G(2,'N&TC!X`5("<9(B=!(P>`>
MB?9)"<9(B<A)`?!%B?9(]]!$B<9-(?-((>A,"=A,C9P#F7F"6DB)\$B)\TC!
MXP5(P>@;2`G82(G+2,'A'HG`2,'K`DD!PT@)RT@#;"2@2(GQB=M$B=A(]]%)
M(=A,(?%,`W0DJ$P)P4R-A`V9>8):2(G!2(G%2,'E!4C!Z1M(">E(B?5(P>8>
M2,'M`HG)2`GU2(G&20'(B>U(]]9$B<%((=Y)(>M(`UPDL$P)WDV-G#:9>8):
M2(G.28G.2<'F!4C![AM,"?9)B<9(P>`>2<'N`HGV20G&2(G(20'S18GV2/?0
M1(G>32'P2"'H3`G`3(V$`YEY@EI(B?!(B?-(P>,%2,'H&T@)V$B)RTC!X1Z)
MP$C!ZP))`<!("<M(`VPDN$B)\8G;1(G`2/?122';3"'Q3`-T),!,"=E,C9P-
MF7F"6DB)P4B)Q4C!Y05(P>D;2`GI2(GU2,'F'DC![0*)R4@)]4B)QDD!RXGM
M2/?61(G92"'>22'H2`-<),A,"<9-C80VF7F"6DB)SDF)SDG!Y@5(P>X;3`GV
M28G&2,'@'DG![@*)]DD)QDB)R$D!\$6)]DCWT$2)QDTA\T@AZ$P)V$R-G`.9
M>8):2(GP2(GS2,'C!4C!Z!M("=A(B<M(P>$>B<!(P>L"20'#2`G+2`-L)-!(
MB?&)VT2)V$CWT4DAV$PA\4P#="383`G!3(V$#9EY@EI(B<%(B<5(P>4%2,'I
M&T@)Z4B)]4C!YAY(P>T"B<E("?5(B<9)`<B)[4CWUD2)P4@AWDDAZT@#7"3@
M3`G>38V<-IEY@EI(B<Y)B<Y)P>8%2,'N&TP)]DF)QDC!X!Y)P>X"B?9)"<9(
MB<A)`?-%B?9(]]!$B=Y-(?!((>A,"<!,C80#F7F"6DB)\$B)\TC!XP5(P>@;
M2`G82(G+2,'A'HG`2,'K`DD!P$@)RT@#;"3H2(GQB=M$B<!(]]%)(=M,(?%,
M`W0D\$P)V4R-G`V9>8):2(G!2(G%2,'E!4C!Z1M(">E(B?5(P>8>2,'M`HG)
M2`GU2(G&20'+B>U(]]9$B=E((=Y)(>A(`UPD^$P)QDV-A#:9>8):2(G.28G.
M2<'F!4C![AM,"?9)B<9(P>`>2<'N`HGV20G&2(G(20'P18GV2/?01(G&32'S
M2"'H3`G828GS2(V<`YEY@EI(B?!)P>,%2,'H&TP)V$F)RTC!X1Z)P$G!ZP)(
M`<-)"<M(`RPD2(GQ18G;B=A(]]%-(=A,(?%,`W0D"$P)P4R-A`V9>8):2(G!
M2(G%2,'E!4C!Z1M(">E(B?5(P>8>2,'M`HG)2`GU2(G&20'(B>U(]]9$B<%,
M(=Y((>M,`UPD$$@)WDF-G#:9>8):2(G.28G.2<'F!4C![AM,"?9)B<9(P>`>
M2<'N`HGV20G&2(G(2`'S18GV2/?0B=Y-(?!((>A,"<!-C80#F7F"6DB)\$F)
M\TG!XP5(P>@;3`G828G+2,'A'HG`2<'K`DD!P$D)RT@#;"082(GQ18G;1(G`
M2/?13"';3"'Q3`-T)"!("=E(B<-(C:P-F7F"6DB)P4C!XP5(P>D;2`G9B<E(
M`<U(B?%(P>8>2,'I`HGK2`GQ2(G&08G/2/?632'X3"'>3`-<)"A,"<9)B=A,
M`WPD,$V-M#:9>8):2(G>2<'@!4C![AM,"<:)]DD!]DB)QDC!X!Y(P>X"18GP
M2`G&3(G`2#'Q2,'H&S'-3(G!2,'A!4F-K"NAZ]EN2`G(2(G92,'C'DC!Z0*)
MP$@)V4@!Q4B)R$&)ZT@Q\$R)VXGV03'&3(G82,'C!4C!Z!M/C;0WH>O9;D@#
M="0X2`G8B<!)`<9,B<!)P>`>2,'H`D2)\TP)P$F)P$DQR(G)2`-,)$!$,<5)
MB=A(C:PNH>O9;DB)WDG!X`5(P>X;3`G&B?9(`?5,B=Y)P>,>2,'N`D&)Z$P)
MWDF)\TDQPXG`2`-$)$A%,=Y-B<-.C;0QH>O9;DR)P4G!XP5(P>D;3`G9B<E)
M`<Y(B=E(P>,>2,'I`D6)\T@)V4B)RT@Q\XGV,=U,B=M(C:PHH>O9;DR)V$C!
MZ!M(P>,%2`-T)%!("=B)P$@!Q4R)P$G!X!Y(P>@"B>M,"<!)B<!),<B)R4@#
M3"1813'&28G83HVT-J'KV6Y(B=Y)P>`%2,'N&TP)QHGV20'V3(G>2<'C'DC!
M[@)%B?!,"=Y)B?-),<.)P$@#1"1@1#'=38G#2(VL*:'KV6Y,B<%)P>,%2,'I
M&TP)V8G)2`'-2(G92,'C'DC!Z0)!B>M("=E(B<M(,?.)]D$QWDR)VTZ-M#"A
MZ]EN3(G82,'C!4C!Z!M("=B)P$D!QDR)P$C!Z`))P>`>2`-T)&A,"<!$B?-)
MB<!),<B)R4@#3"1P1#'%28G82(VL+J'KV6Y(B=Y)P>`%2,'N&TP)QHGV2`'U
M3(G>2<'C'DC![@)!B>A,"=Y)B?-),<.)P$@#1"1X13'>38G#3HVT,:'KV6Y,
MB<%)P>,%2,'I&TP)V8G)20'.2(G92,'C'DC!Z0)%B?-("=E(B<M(,?.)]C'=
M3(G;2(VL**'KV6Y,B=A(P>,%2,'H&T@)V(G`2`'%3(G`2<'@'DC!Z`*)ZTP)
MP$@#M"2`````28G`23'(B<E(`XPDB````$4QQDF)V$Z-M#:AZ]EN2(G>2<'@
M!4C![AM,"<:)]DD!]DR)WDG!XQY(P>X"18GP3`G>28GS23'#B<!(`X0DD```
M`$0QW4V)PTB-K"FAZ]EN3(G!2<'C!4C!Z1M,"=F)R4@!S4B)V4C!XQY(P>D"
M08GK2`G92(G+2#'SB?9(`[0DF````$$QWDR)VTZ-M#"AZ]EN3(G82,'C!4C!
MZ!M("=B)P$D!QDR)P$G!X!Y(P>@"1(GS3`G`28G`23'(B<E$,<5)B=A(C:PN
MH>O9;DB)WDC![AM)P>`%2`.,)*````!,"<:)]D@!]4R)WDG!XQY(P>X"08GH
M3`G>28GS23'#B<!(`X0DJ````$4QWDV)PTZ-M#&AZ]EN3(G!2<'C!4C!Z1M,
M"=F)R4D!SDB)V4C!XQY(P>D"18GS2`G92(G+2#'SB?9(`[0DL````#'=3(G;
M2(VL**'KV6Y,B=A(P>,%2,'H&T@)V(G`2`'%3(G`2<'@'DC!Z`*)ZTP)P$F)
MP$DQR(G)13'&28G83HV\-J'KV6Y(B=Y)P>`%2,'N&TP)QDV)V(GV20'W2<'C
M'DG!Z`)-"=A(`XPDN````$6)_DR)QD@QQHG`2`.$),`````Q]4R)]DR-G"FA
MZ]EN3(GQ2,'F!4C!Z1M("?%(B=Y(P>,>2,'N`HG)2`G>20'+2(GQ1(G=3#'!
M18G`03'/2(GI3HV\.*'KV6Y(B>A(P>$%2,'H&T@)R$R)\4G!YAZ)P$C!Z0))
M`<>XW+P;CTP)\4F)QDP#M"3(````1(G[30'P28G.20GV32'S28G.22'VB?9%
M"?-/C30828G828G;2<'C!4G!Z!M-"=A%B<!-`<9)B>A(P>4>2<'H`D6)\TD)
MZ$B)Q4@#K"30````2`'N3(G%2`G-22'O3(G%2"'-B<E!">],B=U)`?=,B=Y(
MP>4%2,'N&T@)[HGV20'W2(G>2,'C'DC![@)$B?U("=Y(B<-(`YPDV````$@!
MV4B)\TP)PTDAWDB)\TPAPT6)P$$)WDB)ZTD!SDB)Z4C!XP5(P>D;2`G9B<E)
M`<Y,B=E)P>,>2,'I`D2)\TP)V4F)PTP#G"3@````30'828G+20GS32'?28G+
M22'SB?9%"=])B=M-`<=)B=A)P>,%2<'H&TT)V$6)P$T!QTF)Z$C!Y1Y)P>@"
M18G[20GH2(G%2`.L).@```!(`>Y,B<5("<U)(>Y,B<5((<V)R4$)[DR)W4D!
M]DR)WDC!Y05(P>X;2`GNB?9)`?9(B=Y(P>,>2,'N`D2)]4@)WDB)PT@#G"3P
M````2`'92(GS3`G#22'?2(GS3"'#18G`00G?2(GK20'/2(GI2,'C!4C!Z1M(
M"=F)R4D!STR)V4G!XQY(P>D"1(G[3`G928G#3`.<)/@```!-`=A)B<M)"?--
M(=Y)B<M)(?.)]D4)WDF)VTT!QDF)V$G!XP5)P>@;30G818G`30'&28GH2,'E
M'DG!Z`)%B?-)">A(B<5(`ZPD``$``$@![DR)Q4@)S4DA[TR)Q4@AS8G)00GO
M3(G=20'W3(G>2,'E!4C![AM(">Z)]DD!]TB)WDC![@)(P>,>1(G]2`G>2(G#
M2`.<)`@!``!(`=E(B?-,"<-)(=Y(B?-,(<-%B<!!"=Y(B>M)`<Y(B>E(P>,%
M2,'I&T@)V8G)20'.3(G92<'C'DC!Z0)$B?-,"=E)B<-,`YPD$`$``$T!V$F)
MRTD)\TTAWTF)RTDA\XGV10G?28G;30''28G82<'C!4G!Z!M-"=A%B<!-`<=)
MB>A(P>4>2<'H`D6)^TD)Z$B)Q4@#K"08`0``2`'N3(G%2`G-22'N3(G%2"'-
MB<E!">Y,B=U)`?9,B=Y(P>4%2,'N&T@)[HGV20'V2(G>2,'C'DC![@)$B?5(
M"=Y(B<-(`YPD(`$``$@!V4B)\TP)PTDAWTB)\TPAPT6)P$$)WTB)ZTD!STB)
MZ4C!XP5(P>D;2`G9B<E)`<],B=E)P>,>2,'I`D2)^TP)V4F)PTP#G"0H`0``
M30'828G+20GS32'>28G+22'SB?9%"=Y)B=M-`<9)B=A)P>@;2<'C!4T)V$6)
MP$T!QDF)Z$C!Y1Y)P>@"18GS20GH2(G%2`.L)#`!``!(`>Y,B<5("<U)(>],
MB<5((<V)R4$)[TR)W4D!]TR)WDC!Y05(P>X;2`GNB?9)`?=(B=Y(P>,>2,'N
M`D2)_4@)WDB)PT@#G"0X`0``2`'92(GS3`G#22'>2(GS3"'#18G`00G>2(GK
M20'.2(GI2,'C!4C!Z1M("=F)R4D!SDR)V4C!Z0))P>,>1(GS3`G928G#3`.<
M)$`!``!-`=A)B<M)"?--(=])B<M)(?.)]D4)WTF)VTT!QTF)V$G!XP5)P>@;
M30G818G`30''28GH2,'E'DG!Z`)%B?M)">A(B<5(`ZPD2`$``$@![DR)Q4@)
MS4DA[DR)Q4@AS8G)00GN3(G=20'V3(G>2,'E!4C![AM(">Z)]DD!]DB)WDC!
MXQY(P>X"1(GU2`G>2(G#2`.<)%`!``!(`=E(B?-,"<-)(=](B?-,(<-%B<!!
M"=](B>M)`<](B>E(P>,%2,'I&T@)V8G)20'/3(G92<'C'DC!Z0)$B?M,"=E)
MB<-,`YPD6`$``$@#A"1@`0``30'828G+20GS32'>28G+22'SB?9%"=Y)B=M(
M`?!-`<9)B=A)P>,%2<'H&TT)V$6)P$T!QDF)Z$C!Y1Y)P>@"18GS20GH3(G&
M2`G.22'W3(G&2"'.B<E!"?=,B=Y)`<=,B=A(P>@;2,'F!4@)\$B)WDC!XQZ)
MP$C![@))`<>XUL%BRD@)WDB)PT@#G"1H`0``1(G]2`'92(GS3#'#18G`03'>
M2(GK20'.2(GI2,'C!4C!Z1M("=F)R4D!SDR)V4G!XQY(P>D"1(GS3`G928G#
M3`.<)'`!``!-`=A)B<M),?.)]D4QWTF)VTT!QTF)V$G!XP5)P>@;30G818G`
M30''28GH2,'E'DG!Z`)%B?M)">A(B<5(`ZPD>`$``$@![DR)Q4@QS8G)03'N
M3(G=20'V3(G>2,'E!4C![AM(">Z)]DD!]DB)WDC!XQY(P>X"1(GU2`G>2(G#
M2`.<)(`!``!(`=E(B?-,,<-%B<!!,=](B>M)`<](B>E(P>,%2,'I&T@)V8G)
M20'/3(G92<'C'DC!Z0)$B?M,"=E)B<-,`YPDB`$``$T!V$F)RTDQ\XGV13'>
M28G;30'&28G82<'C!4G!Z!M-"=A%B<!-`<9)B>A(P>4>2<'H`D6)\TD)Z$B)
MQ4@#K"20`0``2`'N3(G%2#'-B<E!,>],B=U)`?=,B=Y(P>4%2,'N&T@)[HGV
M20'W2(G>2,'C'DC![@)$B?U("=Y(B<-(`YPDF`$``$@!V4B)\TPQPT6)P$$Q
MWDB)ZTD!SDB)Z4C!XP5(P>D;2`G9B<E)`<Y,B=E)P>,>2,'I`D2)\TP)V4F)
MPTP#G"2@`0``30'828G+23'SB?9%,=])B=M-`<=)B=A)P>,%2<'H&TT)V$6)
MP$T!QTF)Z$G!Z`)(P>4>18G[20GH2(G%2`.L)*@!``!(`>Y,B<5(,<V)R4$Q
M[DR)W4D!]DR)WDC!Y05(P>X;2`GNB?9)`?9(B=Y(P>,>2,'N`D2)]4@)WDB)
MPT@#G"2P`0``2`'92(GS3#'#18G`03'?2(GK20'/2(GI2,'C!4C!Z1M("=F)
MR4D!STR)V4G!XQY(P>D"1(G[3`G928G#3`.<)+@!``!-`=A)B<M),?.)]D4Q
MWDF)VTT!QDF)V$G!Z!M)P>,%30G818G`30'&28GH2,'E'DG!Z`)%B?-)">A(
MB<5(`ZPDP`$``$@![DR)Q4@QS8G)03'O3(G=20'W3(G>2,'E!4C![AM(">Z)
M]DD!]TB)WDC!XQY(P>X"1(G]2`G>2(G#2`.<),@!``!(`=E(B?-,,<-%B<!!
M,=Y(B>M)`<Y(B>E(P>,%2,'I&T@)V8G)20'.3(G92<'C'DC!Z0)$B?-,"=E)
MB<-,`YPDT`$``$T!V$F)RTDQ\XGV13'?28G;30''28G82<'C!4G!Z!M-"=A%
MB<!-`<=)B>A(P>4>2<'H`D6)^TD)Z$B)Q4@#K"38`0``2`'N3(G%2#'-B<E!
M,>Y,B=U)`?9,B=Y(P>4%2,'N&T@)[HGV20'V2(G>2,'C'DC![@)$B?5("=Y(
MB<-(`YPDX`$``$@!V4B)\TPQPT6)P$$QWTB)ZTD!STB)Z4C!XP5(P>D;2`G9
MB<E)`<],B=E)P>,>2,'I`D2)^TP)V4F)PTP#G"3H`0``30'828G+23'SB?9%
M,=Y)B=M-`<9)B=A)P>,%2<'H&TT)V$6)P$T!QDF)Z$C!Y1Y)P>@"18GS20GH
M2(G%2`.L)/`!``!(`>Y,B<5(,<V)R4$Q[TR)W4D!]TR)WDC!Y05(P>X;2`GN
MB?9)`?=(B=Y(P>,>2,'N`D2)_4@)WDB)PT@#G"3X`0``2`'92(GS3#'#18G`
M03'>2HT<,4B)Z4F)[DG!Y@5(P>D;3`GQ`<M,B=E(P>D"2<'C'D@#A"0``@``
M3`G928GK2,'E'DG!ZP)!`=E)">M(B=U,`<!)B<A(P>4%23'P1`'A1`'N13''
M10':3HT$.$B)V$C!Z!M(">A$`<`!PDB)%TR)3PA,B5<02(E/&$B)=R!(@<00
M`@``6UU!7$%=05Y!7\,/'X``````05=!5D%528G]05154TB#[`A(A?]T:$R+
M-<.8(`!-A?9T7`^V!TF)]SP]=&2$P'1@28G\28/$`4$/M@0D/#UT!(3`=>]%
M*>Q)BQY(A=MT+TUCY$R)]0\?`$R)XDR)[DB)W^B*X?__A<!U!T*`/",]="=(
M@\4(2(M=`$B%VW7:2(/$"#'`6UU!7$%=05Y!7\.013'DZ[(/'P!,*?5*C40C
M`4C!_0-!B2](@\0(6UU!7$%=05Y!7\-F+@\?A```````4TB)^TB#[!`/'X0`
M`````$B-="0,,<!(B=_H(?___TB%P'0N2&-4)`Q(BP7PER``2(T$T$B+4`A(
MA=)(B1!TT$B#P`A(BU`(2(722(D0=?#KODB#Q!!;PP\?A```````05<QP$%6
M055!5$F)_%532(GS2(/L&(`^/0^4P$@!PTB)W^AIX?__2(UT)`Q)B<5,B><Q
MP.BG_O__2(7`2(G%#X3[````2(G'Z$/A__]$B>I(.=`/@\\```"+;"0,00^V
M!"0\/0^$A@$``(3`#X1^`0``3(GBZPUF#Q^$``````"$R70,2(/"`0^V"H#Y
M/77P1"GB2(L%)I<@`$*-?"H"2(TLZ.B(XO__2(7`2(E%``^$3@$``(M4)`Q(
MBP4`ER``28U,)`%(BQ3000^V!"2$P(@"=1[K(&8N#Q^$``````!(@\$!#[9!
M_TB#P@&$P(@"=`0\/77JQ@(],<`/'T0```^V#`.(3`(!2(/``83)=?`QP$B#
MQ!A;74%<05U!7D%?PP\?@`````!(@\,!#[9#_TB#Q0&$P(A%_W7MZ],/'P!,
MBS5YEB``28,^``^$I@```$R)\#'M9BX/'X0``````$B#P`B#Q0%(@S@`=?.-
M=0)(8_9(P>8#BP5SIB``A<!T+TR)]^@WXO__2(7`2(D%+98@`'1N3&/]2(G!
M2L=$^0@`````B6PD#.FP_O__#Q\`2(GWQP4SIB```0```.ANX?__2(7`=#Q,
M8_U,B?9(B<=*C13]`````.@3XO__2(G!2(D%V94@`.NR#Q^``````#'2Z9S^
M__^^$````#'MZ73___^X_____^D%____#Q\`055!5%5(B?U32('LF````$B%
M_W0%@#\`=19(@<28````6UU!7$%=PP\?A```````Z/O>__](A<!)B<1TW4R)
MY^BKX?__2(7`2(G##X2?````@'L3+@^$M0```$B#PQ-(B>_H&=___TB)WTF)
MQ>@.W___08U\!0)(8__HH>#__TF)V4F)Q4B)QTF)Z+ET64``2,?"_____[X!
M````,<#H+>+__[\!````2(GB3(GNZ&W>__^#^/],B>]T$(M$)!@E`/```#T`
M0```=&WHX-W__TR)[^BXW?__3(GGZ!#A__](A<!(B<,/A67___\/'T``3(GG
MZ"C?__](B>_H<-[__TB!Q)@```!;74%<05W#9I`/MD,4A,`/A"'___\\+@^%
M-____X![%0`/A`____]FD.DF____#Q\`Z,/^__\/'P#KCF9F9F9F+@\?A```
M````55-(@^P(BSU$E"``Z*_?__^+/3F4(`!(BX#`````2(MH".B9W___BSTC
ME"``#[:8G0```.B'W___2(M`"(/C?P^W0"#!X`<)V&:)10*+/?V3(`#H:-__
M_XL]\I,@`$B+@,````!(BU@(Z%+?__\QTKY36T``2(G'Z#/?__^+/<V3(`!(
MB4,HZ#3?__^+/;Z3(`!(BX#`````2(M8".@>W___2(N`B`8``(L]H9,@`$B)
M0S#H"-___XL]DI,@`$B+@,````!(BU@(Z/+>__\QTDB#N,@!````=!F+/7"3
M(`#HV][__TB+@,@!``!(BY"H````BSU7DR``2(E3..B^WO__2(N`P````(L]
M09,@`$B+0`A(QT!``````.B@WO__2(N`P````(L](Y,@`$B+0`A(QT`@````
M`.B"WO__BST,DR``2(N`P````$B+6`CH;-[__TB+@(`#``!(B4-(2(/$"%M=
MPV8N#Q^$``````!32(G[BSW6DB``Z$'>__](C9#@`0``2(G>OP$```#HC=__
M_X7`=`DQP%O##Q]$``"+/:J2(`#H%=[__XN`^`$``"4`\```/0!```!T'8L]
MC9(@`.CXW?__BX#X`0``)0#P```]`*```'6]2(G?O@(```#HZ=[__X7`#Y3`
M#[;`6\-F9F9F9F8N#Q^$``````!!5+K_#P``28GT54B)_;]Z64``4TB![!`0
M``!(B>9D2(L$)2@```!(B80D"!```#'`Z%K;__^%P'YNC4C_2&/9@#P<`'1:
M2&/82(G:OB\```!(B>?HQ]S__TB%P'1*BSWLD2``Z%?=__](B=E(B>)(B>Y(
MB<?H=M[__TB+A"0($```9$@S!"4H````=39(@<00$```6UU!7,,/'X``````
MA<EUI0\?0`"+/:*1(`#H#=W__TR)XDB)[DB)Q^B_V___Z[?H>-O__P\?A```
M````2(/L"(L]=I$@`.CAW/__N8E90`"ZT!M``+Z364``2(G'2(/$".GVW/__
M9@\?1```2(/L"(L]1I$@`.BQW/__2(G'Z+G___^+/3.1(`#HGMS__T&X4UM`
M`$4QR;KP4T``3(G!OJ]90`!(B<=(@\0(Z0S=__]F9F8N#Q^$``````!32('L
M("```&1(BP0E*````$B)A"08(```,<#H0-K__T&YA5E``$&)P+G$64``,<"Z
M`1```+X!````2(GGZ.[=__^%P'AJ2(VT)!`0``"Z`!```$B)Y^CEV?__A<!(
MB<-X3HUX`4AC_^@3W/__2(7`=#Y(8]M(C;0D$!```$B)QTB)VNBXV___Q@08
M`$B+E"08(```9$@S%"4H````=15(@<0@(```6\,/'X0``````#'`Z]CH-]K_
M_P\?@`````#I.____V9F+@\?A```````055!5$F)_+_264``55-(B?-(@>PX
M$```9$B+!"4H````2(F$)"@0```QP$B-="0<Z"OW__^^+P```$R)YTB)Q>C[
MV?__2(7`=#=,B>:_VUE``#'`Z"?X__],B>!(B[0D*!```&1(,S0E*`````^%
M.P$``$B!Q#@0``!;74%<05W#3(GGZ(?9__](B=^^Z%E``$&)Q>@GW/__2(G#
M#Q]``$B%VW2E@#L`N-!90`!(#T382(7M=!-(B=Y(B>_H;]K__X7`#X2@````
M2(G?Z#_9__^)P4B82(U4`_^`.B]U$)#&`@!(@^H!@^D!@#HO=/%!C40-`3W_
M#P``#X]+____2(U\)"!!N>I90`!)B=BY"5M``+H`$```O@$````QP$R))"3H
M.=S__XL]`X\@`.ANVO__2(UT)"!(C9#@`0``OP$```#H:-C__X7`=1V+/=Z.
M(`#H2=K__XN`^`$``"4`\```/0"```!T%+[H64``,?_H2]O__TB)P^DC____
M2(U\)""^`0```.@DV___A<!UV4B-="0@O]M90`#HX?;__TB-?"0@Z#?9___I
MKO[__^AMV/__9F9F9BX/'X0```````^V#TB)^(3)=!A(C5<!9I"`^2\/M@I(
M#T3"2(/"`83)=>[SPV9F9BX/'X0``````$B%_U-(B?MT+X`_`'0JZ`W8__](
MC50#_T@YTW(,ZT>02(/J`4@YVG0'@#HO=/+K+8`Z+W5_#Q\`OP(```#H?MG_
M_TB%P'1INBX```!FB1!;PP\?@`````"`.B]T"4B#Z@%(.=-R\D@YVG4*Z\,/
M'P"`.B]U"4B#Z@%(.=-R\D@IVDB-0@)(/0`0``!W(TB)WDB#P@&Y`!```+^@
MTF``Z'W9__^XH-)@`%O#9@\?1```,<!;PUN_ZEE``.DQV/__D$B#[$B_[%E`
M`&1(BP0E*````$B)1"0X,<!(BP5@%@``2(E$)!!(BP5<%@``2(E$)!A(BP58
M%@``2(E$)"!(BP54%@``2(E$)"@/MP50%@``9HE$)#`QP.@4]?__,<"_]5E`
M`.@(]?__,<"__5E``.C\]/__,<"_!EI``.CP]/__,<"_#5I``.CD]/__,<"_
M'5I``.C8]/__,<"_TEE``.C,]/__,<"_*5I``.C`]/__,<"_,UI``.BT]/__
M,<"_/5I``.BH]/__,<"_VUE``.B<]/__,<"_1UI``.B0]/__,<"_4%I``.B$
M]/__2(UT)`PQP+];6D``Z+/S__](A<!T#TB)QK\S6D``,<#HO_3__TB-="0,
M,<"_;%I``.B.\___2(7`=`](B<:_?EI``#'`Z)KT__](C70D##'`OXE:0`#H
M:?/__TB%P'0\2(G&O])90``QP.AU]/__,<"^M5I``+\-6D``Z&3T__](BT0D
M.&1(,P0E*````'5:2(/$2,,/'X``````2(UT)`PQP+^96D``Z!?S__](A<!T
M$DB)QK\I6D``,<#H(_3__^NLD$B-="0AOZI:0`"Y"@```/.F=9A(C70D*[\I
M6D``,<#H_//__^N%Z)75__\/'T0``(L%BHL@`(/X_W0%PP\?0`!(@^P8,<"_
M*5I``$B-="0,Z*OR__](A<!T)@^V$#'`A-)T"#'`@/HP#Y7`B05/BR``2(/$
M&,-F+@\?A```````,<#KYV9F9BX/'X0``````$B#[`CH-]7__XG'Z.#4__](
MA<!T"TB+`$B#Q`C##Q\`,<#K]&9F9BX/'X0``````$%7059)B?Y!54&]P5I`
M`$%45;VW6D``4TB#[&A(QT0D(,%:0`!(QT0D*+=:0`!,C60D,$C'1"0PQ%I`
M`$C'1"0XNEI``$C'1"1`OUI``$C'1"1(T5I``$C'1"10`````.LF9@\?1```
M2(G'Z,#7__](A<!T4TB%[70\28L$)$F)[4F#Q`A(B<5(C70D'#'`3(GOZ*GQ
M__](A<!(B<-,B?9T!8`X`'7!3(GO,<#HK_+__TB%[77$2(/$:%M=05Q!74%>
M05_##Q\`3(GWZ"#4__](B=])B<?H%=3__TF-?`<"Z*O5__](B1PD28G'2(G'
M0;GH64``38GPN0E;0`!(Q\+_____O@$````QP.@PU___3(G^3(GO,<#H0_+_
M_^N2D$%7059!54%428G\O])90`!54TB![)B!``!D2(L$)2@```!(B80DB($`
M`#'`2(UT)#Q(QT0D0.A:0`!(QT0D2-!90`!(QT0D4`````!(QX0D@````'Y:
M0`!(QX0DB````'=:0`!(QX0DD````.U:0`!(QX0DF````)1:0`!(QX0DH```
M`/5:0`!(QX0DJ`````````!(QT0D8-Q:0`!(QT0D:/E:0`!(QT0D<`````#H
M;/#__TB%P'0)@#@`#X5&!```,<#HY_W__TB%P$B)PP^$4@0``$B)W^CSTO__
M2(U\``'HB=3__X`[`$F)Q4B)Q70R9@\?1```1`^V`TB)[S'`N0);0`!(Q\+_
M____O@$```!(@\,!2(/%`N@!UO__@#L`==1(C:PDB````+]^6D``ZQ(/'T0`
M`$B#Q0A(BWWX2(7_=#M(C70D/#'`Z,_O__](A<!(B<-TWX`X`'3:2(G'Z*KU
M__^%P'3.2(G?Z"[3__](A<!(B<-U7V8/'T0``$B+7"1`2(7;#X1:`0``@#L`
MO0$```!U)>E+`0``#Q\`2&/%2(M<Q$!(A=L/A#<!``"#Q0&`.P`/A"L!``!(
MB=_H2_7__X7`=-=(B=_HS]+__TB%P$B)PW3'2(G?Z._1__],B>F+,4B#P02-
MEO_^_O[WUB'R@>*`@("`=.B)UL'N$/?"@(````]$UDB-<0)(#T3.`-)(@]D#
M3"GI1(VT"`0$``!-8_9,B??H0M/__T&YZEE``$B)QTB)Q4F)V+D'6T``2,?"
M_____[X!````,<!,B6PD"$C'!"006T``Z+[4__^^P`$``$B)[^BQT/__@_C_
M='R+/7:'(`#HX=+__TB-D.`!``!(B>Z_`0```.@MU/__A<`/A(T```!)BPPD
M2(L]8H<@`$F)Z+K(6T``O@$````QP.@VU/__,<!(BY0DB($``&1(,Q0E*```
M``^%G0@``$B!Q)B!``!;74%<05U!7D%?PP\?`#';Z>K^__^0Z/O/__]$BPA!
M@_D1#X1R____28L,)$B+/?N&(`!)B>BZB%M``+X!````,<#HS]/__S'`ZY</
M'P"+/<*&(`#H+=+__XN`^`$``"4`\```/0!````/A5+___^+/:&&(`#H#-+_
M_XN8_`$``.B1T/__.<,/A33___^+/8.&(`#H[M'__XN`^`$``"7_`0``/<`!
M```/A1/___],B??HX-'__TB-="0\O[I:0`!(B<,QP.A\[?__2(7`2(G'#X3%
M!P``Z.O0__])BSPD2(G&Z/_U__](A<!)B<4/A*@'``!,B>_H^\___X/X`WXV
M2&/0OQ5;0`"Y!0```$F-=!7\\Z9U((/X!`^$>@8``(/H!$B808!\!?\O#X1I
M!@``9@\?1```,<#H.?K__X7`=18Q]DR)[^C[T?__A<")1"0@#X5/`0``OK5:
M0`"_*5I``#'`Z/[M___H"<___TC'1"0(4UM``(D$)$&YZEE``$F)Z+DN6T``
M2,?"_____[X!````2(G?,<#HJ=+__T4QY.M,#Q]``.AKSO__@S@1=5!!@\0!
MZ+W.__](QT0D$%-;0`")!"1!N>I90`!$B60D"$F)Z+D\6T``2,?"_____[X!
M````2(G?,<#H6-+__[[``0``2(G?Z$O.__^#^/]TIDB)[^C^S?__2(G>O])9
M0``QP.A/[?__2(G?Z.?Y__](B=CIN_W__P\?@`````!(B<=(B40D(.C+^?__
M2(M$)"!(B<?H?L___^F5_?__O]Q:0`"]`0```.L5#Q]$``!(8\6#Q0%(BWS$
M8$B%_W0K2(UT)#PQP.C,Z___2(7`=-^`.`!TVDB)Q^@ZS___2(7`2(G#=,KI
M8OO__T"W#;OA6D``Z6+[__^Z`@```$C'QN[___^)QT&)QNA*T?__2(VT)(`!
M``"Z!@```$2)]^@ES___@+PD@`$```!U#H"\)($!``!##X0M!0``BWPD(#'2
M,?;H$-'__[B)J\WO2,>$)``!```!(T5G2,>$)!@!``!V5#(02(F$)`@!``"X
M_MRZF$C'A"0H`0```````$B)A"00`0``N/#ATL-(QX0D,`$```````!(B80D
M(`$``$B-A"0X`0``QX0D>`$```````!(B40D*)"+?"0@2(VT)(`!``"Z`(``
M`.AZSO__A<!)B<=!B<0/CID!``!(B[0D*`$``$ECQXT4QD@YUDB+M"0P`0``
M=@1(@\8!2,'H'4B)E"0H`0``2`'P2(F$)#`!``!(8X0D>`$``(7`#X1&`0``
MND````!(C;P$.`$``$B-M"2``0``*<)!.==!#T[73&/J08G43(GJZ%K.__^+
MA"1X`0``1`'@@_A`B80D>`$```^%4/___T2)^$B-O"0``0``1"G@08G$2(V$
M)(`!``!)`<7H']/__P\?@`````!!@_P_#XZE````18GF38GO#Q^$``````!)
MBP](C;PD``$``$&#[D!)@\=`2(F,)#@!``!)BT_(2(F,)$`!``!)BT_02(F,
M)$@!``!)BT_82(F,)%`!``!)BT_@2(F,)%@!``!)BT_H2(F,)&`!``!)BT_P
M2(F,)&@!``!)BT_X2(F,)'`!``#HC-+__T&#_C]_AD&#[$!$B>+!Z@:)T,'B
M!DB#P`%!*=1(P>`&20'%2(M\)"A)8]2Y2````$R)[N@TS?__1(FD)'@!``#I
M5_[__P\?@`````!,C:PD@`$``.D;____BWPD(.A:S/__3(ND)"@!``!,BZPD
M,`$``$R)X$C!Z`.#X#^-2`%(8]#&A!0X`0``@(/Y.`^/=@(``+HW````2&/)
M,?8IPDB-O`PX`0``2&/2Z-W+__],B>A(C;PD``$``$2(K"1S`0``2,'H&$2(
MI"1W`0``3(V\)-````"(A"1P`0``3(GH2,'H$$V-=RB(A"1Q`0``3(GH3(VL
M)+$```!(P>@(B(0D<@$``$R)X$C!Z!B(A"1T`0``3(G@2,'H$(B$)'4!``!,
MB>!-B?Q(P>@(B(0D=@$``.A5T?__2(N$)``!``!(B<*(A"2S````2,'J&$0/
MML*(E"2P````2(G"2,'J$(B4)+$```!(B<)(BX0D"`$``$C!Z@B(E"2R````
M2(G"B(0DMP```$C!ZAB(E"2T````2(G"2,'J$(B4)+4```!(B<)(BX0D$`$`
M`$C!Z@B(E"2V````2(G"B(0DNP```$C!ZAB(E"2X````2(G"2,'J$(B4)+D`
M``!(B<)(BX0D&`$``$C!Z@B(E"2Z````2(G"B(0DOP```$C!ZAB(E"2\````
M2(G"2,'J$(B4)+T```!(B<)(BX0D(`$``$C!Z@B(E"2^````2(G"B(0DPP``
M`$C!ZAB(E"3`````2(G"2,'J$(B4),$```!(B<)(P>H(B)0DP@```.D0````
M#Q^``````$4/MD4`28/%`4R)YS'`N0);0`!(Q\+_____O@$```!)@\0"Z/#,
M__]-.?1UT\:$)/@`````2,=$)`A36T``3(D\)$&YZEE``$F)Z+D?6T``2,?"
M_____[X!````2(G?,<#HLLS__^EG^O__38MD)`A-A>0/A(_Y__],B>?H1\G_
M_TB#^`,/AGWY__])C70$_+\:6T``N04```#SIDT/1.SI8_G__TACR;H_````
M,?9(C;P,.`$``"G"2&/2Z&?)__](C;PD``$``.A:S___2(V4)#@!``"Y!P``
M`#'`2(G7\TBKZ6/]__^`O"2"`0``00^%Q?K__X"\)(,!``!##X6W^O__@+PD
MA`$``$@/A:GZ__^`O"2%`0``10^%F_K__T2+="0@N@(```!(Q\;&____1(GW
MZ)_+__](C;0D@`$``+HI````1(GWZ'K)__](C80D@`$``$C'1"0(4UM``$B)
M!"3IVO[__^AKR/__38LL).E/^/__9I!!54%455-(@^P8BSU@?B``Z,O)__](
MC70D#,:`F0````&_#5I``#'`Z'/E__](A<!T"8`X,0^$E0(``#'`Z*[P__^+
M/2A^(`#HD\G__[D+````N@$```"^35M``$B)Q^@<R?__2(7`#X2\````@SU,
MCB```4B+0!!,BV@H#XZG````O0@````QV^LR#Q]$``!)BW0D$$B+!1R.(`!(
MBSPHZ,O(__^%P'5O@\,!BP4.CB``2(/%"(U3`3G"?6&+/:U](`#H&,G__S')
MB=I,B>Y(B<?H^<G__TB%P'0\3(L@08M$)`PE``0@`#T`!```=*"+/7I](`#H
MY<C__TR)YKD"````,=)(B<?HL\?__TB)QNN#9@\?1```BP6BC2``C5#_.=H/
MA#\!``"+/4%](`#HK,C__[D$````N@$```"^4EM``$B)Q^@UR/__2(7`2(G#
M=#-(BT`0BST3?2``2(LHZ'O(__^Z5%M``$B)QTB)[N@KQ___2(M#$$B+&/9#
M#D`/A2H!``"+/>1\(`#H3\C__[D$````N@$```"^65I``$B)Q^C8Q___2(7`
M2(G%=#U(C70D##'`O]M90`#HW^/__TB%P$B)PP^$HP$``$B+11"+/9E\(`!,
MBR#H`<C__TB)VDB)QTR)YNBSQO__BSU]?"``Z.C'__^+/7)\(`#&@)D`````
MZ-;'__](C70D#$C'@%@'````````O])90``QP.AZX___2(7`2(G#2(D%E8P@
M``^$KP```+[``0``2(G'Z%K%__^#^!%T#(U0`8/Z`0^'E@$``$B#Q!A;74%<
M05W#9@\?1```@_@!#XZX_O__NP$```!F+@\?A```````BSWJ>R``@\,!Z%+'
M__],B>Y(B<?H)\7__SD=(8P@`'_?Z8/^__]F+@\?A```````BSVZ>R``Z"7'
M__](B=Y(B<?H>L?__^F[_O__#Q]$``"`>`$`#X1H_?__9@\?1```Z5;]__\/
M'P!(BSW)BR``Z(SQ__](A<!(B07*BR``#X3?````2(M%$$R+):F+(`!(BQB+
M0PPE``0@`#T`!```#X69````2(M[$$R)YNCOQ___08G$2(M%$$B+&(M3#('B
M``0@`('Z``0``'502(M3$$B+!6&+(`!$B>&_2%Q``$B+,#'`Z)?&__\/'X``
M````2(L%08L@`(L]\WH@`$R+($B+11!(BQCH5,;__TR)YDB)W^B)Z/__Z5'^
M__^+/<YZ(`#H.<;__S'2N0(```!(B=Y(B<?H!\7__TB)PNN2BSVL>B``Z!?&
M__^Y`@```$B)QS'22(G>Z.7$__](B<?I1O___[\@7$``Z!/&__^)P4B+!<**
M(`!(B=J_<%Q``$B+,#'`Z/C%__\/'X0``````%5(B?U32(/L".@2[/__#[8(
M2(G#A,ET&DB-4`$/'T``@/DO#[8*2`]$VDB#P@&$R77N,<#HA^[__X7`=!U(
MA>UT&(!]``!T$KX06T``2(G?Z"O'__](.=AT!TB#Q`A;7<-(@\0(2(GO6UWI
M4>3__Y!(@^P(BSWF>2``Z%'%__^^_____TB)Q^ADQ/__BSW.>2``Z#G%__\Q
MTKX0/D``2(G'2(/$".G&QO__9@\?1```2(T%D7D@`$B%P'0,2(L-A7D@`.DX
MQ/__,<GK]P\?0`!(B6PDV$R)9"3@2(TMYW0@`$R-)=AT(`!(B5PDT$R);"3H
M3(ET)/!,B7PD^$B#[#A,*>5!B?])B?9(P?T#28G5,=OH"<+__TB%[70:#Q]`
M`$R)ZDR)]D2)_T'_%-Q(@\,!2#GK=>I(BUPD"$B+;"003(MD)!A,BVPD($R+
M="0H3(M\)#!(@\0XPP\?@`````#SPP``2(/L"$B#Q`C#`````0`"`"5S+R5S
M`"]P<F]C+W-E;&8O97AE`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`+@!0
M05)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$52
M3#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P!005)?05)'5E\P
M`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]
M`#$`3$E"4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(`%5315(`
M4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>``E<R5S)7,E
M<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`+64`+2T``%]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``
M`````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E
M<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``````````(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X
M96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R
M7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U
M;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@
M,34X"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI4
M96UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@
M1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D
M:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S
M"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O
M;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N
M('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@
M("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@
M=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL
M(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y
M('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N
M(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@
M("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@
M("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U0
M3$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)
M6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@
M("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@
M("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G
M(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@
M,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^
M9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S
M92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q
M*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@
M?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?
M:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@
M)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!
M4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D
M,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@
M)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=6
M7R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC
M(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I
M9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU3
M5VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@
M<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE
M<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T
M>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D[
M"@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@
M7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N
M<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I
M+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E
M86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T
M.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?
M1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@
M("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*
M("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@
M("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D
M97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@
M("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X
M="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U
M="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@
M("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@
M96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D
M("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M
M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@
M/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@
M(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N
M(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@
M("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F
M.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["B`@("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@
M("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D
M9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`
M24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PH*("`@("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@
M("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@
M("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@
M("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K
M97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@
M("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@
M)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*
M("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO
M9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M
M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R
M(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@
M("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]
M+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[
M>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*
M("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD[
M"B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@
M9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D
M(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE
M(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L
M;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7
M:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M
M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@
M(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@
M("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G
M<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@
M("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A
M<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@
M<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L
M92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*
M(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T
M86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O
M<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@
M("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R
M"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L
M;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y
M7W!A<@H@("`@*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B
M87!P;F%M92`M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!
M4D=6(BP*("`@(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L
M(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@
M:71S96QF("AB=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER
M;VYM96YT(&%N9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E
M<2`G+2UR975S92<I('L*("`@("`@("!S:&EF="!`05)'5CL*("`@("`@("`D
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D
M9%]T;U]I;F,["B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@
M("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["@H@("`@("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@
M("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@("`@("!E
M=F%L(")U<V4@)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G02<I('L*("`@("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)T\G*2!["B`@("`@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@
M("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("`@("`D
M8G5N9&QE(#T@)V%L;"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2![
M"B`@("`@("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@
M("1C86-H95]N86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M('-H:69T*$!!4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("`@("`@9&5L971E("1%3E9[)U!!
M4E]414U0)WT["B`@("`@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@
M("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("`@("`F
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@
M("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@
M("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC
M(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U
M='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("![
M"B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@
M("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P
M87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F
M:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O
M<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO
M9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@
M("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G
M(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@
M("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%
M5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@
M("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@
M?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![
M>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@
M>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A
M<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I
M<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T
M(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE
M("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A
M=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P
M+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@
M;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;
M)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D
M:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K
M97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T
M:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@
M("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]
M?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D
M8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@
M(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET
M7VEN8R@I.PH*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@
M;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L
M96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T10
M04XO"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@
M(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@
M("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA
M=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C
M(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@
M;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H
M<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N
M:6YG+`H@("`@("`@(",@22!F86EL960N("TM(%-T969F96X*("`@("`@("!M
M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F
M:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK
M(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@
M("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@
M("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@
M("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I
M<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D
M9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@
M;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF
M("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N
M97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA
M;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J
M;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F
M:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@
M<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT
M96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@
M("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L
M("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@
M("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@
M)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%
M.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@
M(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N
M(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I
M.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@
M("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T
M94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@
M("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@
M?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!
M4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D
M8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!
M+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI3
M2$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I
M(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C
M='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE
M(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@
M("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I
M;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<
M;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@
M)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E
M("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M
M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@
M:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@
M("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@
M)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@
M("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<[
M"B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D
M0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]
M("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@
M("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@
M("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@
M("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@
M("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@
M("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@
M("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@
M("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@
M)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC
M871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@
M("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU
M;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H
M4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES
M=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@
M("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC
M('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S
M86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI
M8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@
M<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@
M>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@
M1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@
M("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A
M=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@
M9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@
M(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-
M4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO
M861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T
M.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@
M(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R
M97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@
M("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E
M<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@
M(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E
M<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R
M97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI:
M:7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*
M("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q
M=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E
M=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H
M92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT
M;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!4
M96UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*
M("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@
M("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@
M("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@
M+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H
M(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N
M86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O
M<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M
M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@
M)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G
M4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O
M7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E
M;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PH@("`@("`@(&UK
M9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%
M04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@
M("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@
M("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*
M("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@
M("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@
M(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@
M("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O
M<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y
M"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@
M("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@
M)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT
M+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D
M9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M
M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE
M.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I
M;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F
M:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I
M.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@
M;&EV97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B
M(%]S971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@
M("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\
M/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA
M;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]0
M4D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@
M?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*
M("`@("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!]
M(&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@
M<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@
M("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P
M<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*
M"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@
M("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@
M("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I
M+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E
M='5R;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@
M("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C
M;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@
M("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[
M4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%2
M7T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H
M)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%
M3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH
M7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I
M970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`
M7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*
M("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@
M("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N
M9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP
M86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R
M;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,0H*7U]%3D1?
M7PH```````````````````#`0P$;`SOT````'0```,AB__]``0``*&?__^@%
M```T:?__$`$``"AJ__]H`0``&('__[@!``#8@?__&`(``#B"__\X`@``2(3_
M_X@"``"8A?__V`(```B'__\(`P``F(?__R@#``!HB/__8`,``)B(__]X`P``
MZ(C__Y`#``"HB?__N`,``+B)___0`P``>(O__Q`$``"HB___*`0``&B,__]8
M!```2([__W@$``"HCO__F`0``-B.__^X!```^(___P@%``!XF___6`4``(B?
M__^8!0``^)___]`%```XH/__$`8``%B@__\H!@``Z*#__U`&````````%```
M```````!>E(``7@0`1L,!PB0`0<0%````!P````<:/__*@``````````````
M%``````````!>E(``7@0`1L,!PB0`0``)````!P```"`8?__8`0````.$$8.
M&$H/"W<(@``_&CLJ,R0B`````$P```!$````N&C__^D6````0@X0CP)(#AB.
M`T(.((T$0@XHC`5!#C"&!D$..(,'1P[(!`/'%@XX00XP00XH0@X@0@X80@X0
M0@X(````````7````)0```!8?___M@````!"#A"/`D(.&(X#0@X@C01%#BB,
M!4$.,(8&00XX@P=$#D`"<0H..$,.,$$.*$(.($(.&$(.$$(."$(+6PXX00XP
M00XH0@X@0@X80@X00@X('````/0```"X?___6`````!!#A"#`D<.(`).#A!!
M#@A,````%`$``/A___\-`@```$(.$(\"1`X8C@-"#B"-!$(.*(P%1`XPA@9!
M#CB#!T<.4`,``0H..$$.,$$.*$(.($(.&$(.$$(."$@+`````$P```!D`0``
MN('__T(!````0@X0C0)"#AB,`T$.((8$1`XH@P5'#L`!40H.*$$.($$.&$(.
M$$(."$D+`M<*#BA!#B!!#AA"#A!"#@A#"P``+````+0!``"X@O__9@$```!!
M#A"&`D$.&(,#1`X@`UT!#AA!#A!!#@@`````````'````.0!``#X@___@0``
M``!!#A"#`FD*#@A&"P)0#@@T````!`(``&B$___(`````$(.$(P"20X8A@-)
M#B"#!$<.L"`">0H.($$.&$$.$$(."$@+`````!0````\`@```(7__RH`````
M1`X080X(`!0```!4`@``&(7__T0`````1`X0>PX(`"0```!L`@``4(7__[D`
M````00X0@P)'#K!``IX*#A!!#@A)"P`````4````E`(``.B%__\%````````
M```````\````K`(``."%__^S`0```$(.$(T"0@X8C`-)#B"&!$$.*(,%2@[@
M(`)B"@XH00X@00X80@X00@X(00L`````%````.P"``!@A___)```````````
M````+`````0#``!XA___OP````!$#A"#`@),"@X(2`L"40H."$<+0PH."$$+
M00X(````'````#0#```(B/__VP$```!$#E`#?`$*#@A("P`````<````5`,`
M`,B)__]4`````%0.('$*#@A+"P```````!P```!T`P``"(K__R0`````1`X0
M6`H."$0+````````3````)0#```8BO__'P$```!"#A"/`D(.&(X#10X@C01(
M#BB,!4$.,(8&1@XX@P=$#J`!`IX*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"P``
M``!,````Y`,``.B*__]^"P```$(.$(\"0@X8C@-"#B"-!$(.*(P%20XPA@9!
M#CB#!T<.T(,"`\$""@XX00XP00XH0@X@0@X80@X00@X(1`L``#P````T!```
M&);__P@$````0@X0C0)"#AB,`T$.((8$00XH@P5$#D`#40(*#BA!#B!!#AA"
M#A!"#@A'"P`````T````=`0``.B9__]O`````$$.$(8"1`X8@P-$#B`"50H.
M&$$.$$$."$$+1`X81`X000X(`````!0```"L!```()K__SH`````1`X0<0X(
M`"0```#$!```.&'__PP"````00X0@P)$#D`#E`$*#A!##@A!"P`````4````
M[`0``"":__\<```````````````D````!`4``"B:__^)`````$J&!HP%9@Y`
M@P>-!(X#CP("6`X(````%````"P%``"0FO__`@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'`B0```````4")`````````````````
M``$``````````0`````````!``````````T"`````````0`````````8`@``
M``````$`````````(@(````````!`````````'$"`````````0````````"^
M`P````````P`````````(!M````````-`````````&190```````&0``````
M``#`S6```````!L`````````"``````````:`````````,C-8```````'```
M```````(`````````/7^_V\`````F`)````````%`````````)`-0```````
M!@````````"@`T````````H`````````2P4````````+`````````!@`````
M````%0````````````````````,``````````-!@```````"`````````'@&
M````````%``````````'`````````!<`````````J!1````````'````````
M`#`40```````"`````````!X``````````D`````````&`````````#^__]O
M`````+`30```````____;P`````"`````````/#__V\`````W!)`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````-C-8````````````````````````````%8;0```````
M9AM```````!V&T```````(8;0```````EAM```````"F&T```````+8;0```
M````QAM```````#6&T```````.8;0```````]AM````````&'$```````!8<
M0```````)AQ````````V'$```````$8<0```````5AQ```````!F'$``````
M`'8<0```````AAQ```````"6'$```````*8<0```````MAQ```````#&'$``
M`````-8<0```````YAQ```````#V'$````````8=0```````%AU````````F
M'4```````#8=0```````1AU```````!6'4```````&8=0```````=AU`````
M``"&'4```````)8=0```````IAU```````"V'4```````,8=0```````UAU`
M``````#F'4```````/8=0```````!AY````````6'D```````"8>0```````
M-AY```````!&'D```````%8>0```````9AY```````!V'D```````(8>0```
M````EAY```````"F'D```````+8>0```````QAY```````#6'D```````.8>
M0```````]AY````````&'T```````!8?0```````)A]````````V'T``````
M`$8?0```````5A]```````!F'T```````'8?0```````AA]```````"6'T``
M``````````````````````````#_____`````+A<0```````1T-#.B`H1&5B
M:6%N(#0N."XR+3$I(#0N."XR`$=#0SH@*$1E8FEA;B`T+C<N,RTW*2`T+C<N
M,P``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N
M8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I
M;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N
M=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI
M;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T
M+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````
M```````````````````````````````````````````````````````````+
M`````0````(`````````.`)````````X`@```````!P`````````````````
M```!````````````````````$P````<````"`````````%0"0```````5`(`
M```````@````````````````````!````````````````````"$````'````
M`@````````!T`D```````'0"````````)`````````````````````0`````
M```````````````T````]O__;P(`````````F`)```````"8`@````````0!
M````````!0`````````(````````````````````/@````L````"````````
M`*`#0```````H`,```````#P"0````````8````!````"``````````8````
M`````$8````#`````@````````"0#4```````)`-````````2P4`````````
M``````````$```````````````````!.````____;P(`````````W!)`````
M``#<$@```````-0`````````!0`````````"``````````(`````````6P``
M`/[__V\"`````````+`30```````L!,```````"```````````8````"````
M"````````````````````&H````$`````@`````````P%$```````#`4````
M````>``````````%``````````@`````````&`````````!T````!`````(`
M````````J!1```````"H%````````'@&````````!0````P````(````````
M`!@`````````?@````$````&`````````"`;0```````(!L````````:````
M````````````````!````````````````````'D````!````!@````````!`
M&T```````$`;````````8`0``````````````````!``````````$```````
M``"$`````0````8`````````H!]```````"@'P```````,(Y````````````
M```````0````````````````````B@````$````&`````````&190```````
M9%D````````)````````````````````!````````````````````)`````!
M`````@````````!P64```````'!9````````"%\```````````````````@`
M``````````````````"8`````0````(`````````>+A```````!XN```````
M`/0````````````````````$````````````````````I@````$````"````
M`````'"Y0```````<+D```````!T!0``````````````````"```````````
M`````````+`````.`````P````````#`S6```````,#-````````"```````
M``````````````@```````````````````"\````#P````,`````````R,U@
M``````#(S0````````@````````````````````(````````````````````
MR`````$````#`````````-#-8```````T,T````````(````````````````
M````"````````````````````,T````&`````P````````#8S6```````-C-
M````````(`(````````&``````````@`````````$`````````#6`````0``
M``,`````````^,]@``````#XSP````````@````````````````````(````
M``````@`````````VP````$````#``````````#08````````-````````!`
M`@``````````````````"``````````(`````````.0````!`````P``````
M``!`TF```````$#2````````(`````````````````````@`````````````
M``````#J````"`````,`````````8-)@``````!@T@```````&@0````````
M```````````@````````````````````[P````$````P````````````````
M````8-(````````X`````````````````````0`````````!``````````$`
M```#`````````````````````````)C2````````^```````````````````
1``$`````````````````````
